@@ -1,6 +1,10 @@
 """Cadence Virtuoso SKILL library"""
+import pluggy
+
 from .LibUtility import *
 from .SchUtility import *
 from .ConfigUtility import *
 
-__version__ = '0.2.1'
\ No newline at end of file
+__version__ = '0.3.0'
+
+hookimpl = pluggy.HookimplMarker("virtue")
